#
# spec file for package mawk
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _upver 1.3.4
%define _datever 20230525
Name:           mawk
Version:        %{_upver}.%{_datever}
Release:        1.2
Summary:        Implementation of New/POSIX AWK
License:        GPL-2.0-only
URL:            https://invisible-island.net/mawk/mawk.html
Source0:        https://invisible-island.net/archives/mawk/mawk-%{_upver}-%{_datever}.tgz
Source1:        https://invisible-island.net/archives/mawk/mawk-%{_upver}-%{_datever}.tgz.asc
Source2:        %{name}.keyring
# PATCH-FIX-OPENSUSE -- bmwiedemann -- drop timestamp / for build-compare
Patch0:         reproducible.patch

%description
mawk is an interpreter for the AWK Programming Language. It implements the AWK
language as defined in Aho, Kernighan and Weinberger, The AWK  Programming
Language, Addison-Wesley Publishing, 1988. Furthermore, it conforms to the
POSIX 1003.2 (draft 11.3) definition of the AWK language and additionally
provides a small number of extensions.

%prep
%autosetup -n mawk-%{_upver}-%{_datever} -p1
chmod 755 examples/*

%build
# without --enable-warnings several functions will not be marked with gcc's
# noreturn attribute and produce warnings when $RPM_OPT_FLAGS contains -Wall
%configure \
  --enable-warnings
%make_build

%install
%make_install

%check
%make_build check

%files
%license COPYING
%doc ACKNOWLEDGMENT CHANGES README examples/
%{_bindir}/mawk
%{_mandir}/man1/mawk.1%{?ext_man}

%changelog
* Thu Jun 22 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.3.4-20230525:
  * see provided CHANGES for detailed list of changes
- Refresh source urls and gpg keyring
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Thu Sep 23 2021 Manfred Schwarb <manfred99@gmx.ch>
- remove update-alternatives support, as on linux systems GNU software
    (i.e. gawk in this case) is usually considered the default implementation.
- use %%make macros
- modify patch reproducible.patch to use __DATE__ and __TIME__, as
    these macros are reproducible now (SOURCE_DATE_EPOCH support since GCC 7)
* Thu Feb  4 2021 Ludwig Nussel <lnussel@suse.de>
- fix update-alternatives usage. Needs to be in %%postun according to
  https://en.opensuse.org/openSUSE:Packaging_Multiple_Version_guidelines#update-alternatives_mechanism
* Wed Dec 16 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Wed May 20 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 1.3.4-20200120
  * fix typos found with codespell.
  * when reading input in interactive mode, provide for extending the
    buffer size for very long lines (Original-Mawk #59).
  * correct line-number shown in too-many-arguments error message for
    the case where the function is a forward reference (report by "mukti").
  * fix install for manpage when configure --srcdir option is used
    (report by Rajeev V Pillai).
  * use both CFLAGS/LDFLAGS when linking in makefile (report by Rajeev V Pillai).
  * fix clang-9 warning in bi_funct.c (report by Rajeev V Pillai).
  * minor improvement to gcc warning options, from vile
  * improve manpage formatting, e.g., for man2html
  * improve debug-traces
  * eliminate non-portable tdestroy() from zmalloc no-leaks code.
  * revert a change for memory-leaks which made the forced-exit via a
    user function inconsistent with earlier versions (report by Sihera Andre).
  * amend a change for memory-leaks to avoid a double-free (Original-Mawk #56).
* Wed Jul 11 2018 mpluskal@suse.com
- Update to version 1.3.4-20171017:
  * add Debian compile/link flags to test-package.
  * cleanup spurious warnings from latest gcc.
  * changes for Original-Mawk #48:
    + add checks for stack overflow and underflow
    + increase stack limit to 1024
  * updated configure macros
  * update config.guess and config.sub
  * add runtime check for assignments to OFMT and CONVFMT to ensure
    they use a single parameter (Original-Mawk #47).
  * repair build for --with-valgrind, broken in 20160930 const-fixes.
  * correct sign-extension from 20160615 change to rand() (report by
    Christian Neukirchen).
  * allow single-quote as a flag in printf, to complete the change
    for LC_NUMERIC in 20121129 (report by Graham Monteith).
  * revert one of the fixes made for a Coverity warning about loss of
    precision in 20121209, which unnecessarily exposed a different
    problem (Original-Mawk #45).
  * simplify "system()" function by calling C "system()" function, and
    use POSIX macros for wait-status to provide a less-ambiguous return
    value (suggested by Aharon Robbins).
  * add a null-pointer check in bi_mktime (patch by Ismael Luceno).
  * escape '/' in range for test/reg4.awk to allow test-comparison with
    gawk and BWK.
  * updated configure macros, e.g., for compiler warnings and static
    analysis:
    + CF_CC_ENV_FLAGS
    + CF_GNU_SOURCE
    + CF_PROG_LINT
    + CF_RAND
    + CF_XOPEN_SOURCE
  * minor build-fix for HPUX 11.11 "make", which is confused by the
    recursive use of "make" in clean/distclean rules.
  * amend fix for Gentoo #424137 to eliminate a memory leak when opening
    files (Original-Mawk #44).
  * update config.guess and config.sub
  * correct range when using system rand() function, which was 0..2
    rather than 0..1 on BSD systems (report/patch by Masaki Waga).
  * correct order of checks for machine state in REtest which caused an
    out-of-bounds reference (Original-Mawk #36).
  * update COPYING from
    https://www.gnu.org/licenses/old-licenses/gpl-2.0.txt
    (Original-Mawk #38).
  * minor updates to configure script macros
  * update config.guess and config.sub
* Mon Jan 23 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Mon Nov  9 2015 p.drouand@gmail.com
- Update to version 1.3.4-20150503
  * add --with-man2html configure option
  * improve description of -W options and how they can be combined into
    a comma-separated list (adapted from Leif LeBaron).
  * modify parsing for -Wexec to permit its value to be separated by '='
    in addition to a space, for consistency with the other -W options.
  * cosmetic changes to configure script macros, from work on xterm.
  * update config.guess and config.sub
  For previous changes, please read the CHANGES file
- Remove patches; fixed on upstream release
  * mawk-1.3.4-fix-make-check-path-handling.patch
  * mawk-1.3.4-fix-regex-matching.patch
* Sat Apr  4 2015 mpluskal@suse.com
- Add gpg signature
- Cleanup spec file with spec-cleaner
* Sat Feb  8 2014 gber@opensuse.org
- adjust update-alternative usage to packaging policy
  (see http://lists.opensuse.org/opensuse-packaging/2014-02/msg00024.html)
- move mawk to /usr/bin and add symlink in /bin
* Tue May 15 2012 gber@opensuse.org
- package COPYING
- simplify installation
- make example scripts executable
* Tue Jan 10 2012 gber@opensuse.org
- added mawk-1.3.4-fix-regex-matching.patch which adds limit-check
  after processing match(test, "[^0-9A-Za-z]") to ensure the
  internal trailing null of the test-string is not mistaken for
  part of the string (backported from development snapshot,
  bnc#740484)
- specfile cleanup
* Mon Feb 22 2010 guido+opensuse.org@berhoerster.name
- use update-alternatives
* Fri Feb 19 2010 guido+opensuse.org@berhoerster.name
- add copyright note for integration into Factory
* Fri Feb 19 2010 guido+opensuse.org@berhoerster.name
- cleaned up specfile, added explanatory comment
* Wed Feb 17 2010 guido+opensuse.org@berhoerster.name
- added check section
- use external changelog
- dropped mawk-1.3.4-fix-gcc-bogus-warning.patch, passing --enable-warnings to
  configure correctly marks the affected functions with GCC's noreturn
  attribute (thanks to T. Dickey for clarifying)
- added patch fixing path handling issues with the make check target and
  associated scripts
* Wed Dec 23 2009 guido+opensuse.org@berhoerster.name
- initial packaging of mawk
